# FancyKimai

This is a CLI created to interact with Kimai2 without needing to open the browser.

## Installation

```bash
pip install fancykimai
```

## Usage

```bash
kimai --help
Usage: kimai [OPTIONS] COMMAND [ARGS]...

Options:
  --help  Show this message and exit.

Commands:
  activities
  config      Configuration commands
  customers   Customer commands
  login
  projects    Project commands
  teams
  timesheets  Timesheet commands
```

## License

[GNU GPLv3](LICENSE)
